/*
MIDI messages are generally represented in hexadecimal format, and the hexadecimal 
code for a MIDI note message is 0x9.
In a MIDI message, the first byte (8 bits) specifies the message type and channel, 
and the second and third bytes specify the note number and velocity, respectively. 
For a MIDI note-on message, the first byte is 0x9, and the second byte contains the 
MIDI note number, while the third byte contains the velocity (how hard the note is 
played).
For example, a MIDI note-on message for middle C (MIDI note number 60) played at full 
velocity (127) would be represented in hexadecimal format as 0x90 |0x3C | 0x7F, where 0x90 
is the message type and channel (note-on message on channel 1), 0x3C is the MIDI note
number for middle C, and 0x7F is the velocity.
Similarly, a MIDI note-off message, which is used to stop the sound of a previously 
played note, is represented by a hexadecimal code of 0x8.
*/

#include <UHS2-MIDI.h>
USB Usb;
UHS2MIDI_CREATE_DEFAULT_INSTANCE(&Usb);
#define BAUD_RATE 31250 // Set the baud rate for MIDI serial communication

void handleNoteOn(byte channel, byte pitch, byte velocity)  // Function to handle incoming note on messages
{
  Serial.write(0x90 | channel);
  Serial.write(pitch);  
  Serial.write(velocity);
}
void handleNoteOff(byte channel, byte pitch, byte velocity)
{
  Serial.write(0x80 | channel);
  Serial.write(pitch);  
  Serial.write(velocity);
}
void handleProgramChange(byte channel, byte number)
{
  Serial.write(0xC0 | channel); // Send the status byte C + MIDI channel value ("0" = Midi channel 1)
  Serial.write(number); // Send the program number  
}
void handleControlChange(byte channel, byte CCtype, byte value)
{
  Serial.write(0xB0 | channel);
  Serial.write(CCtype);
  Serial.write(value);
}

void setup() 
{
  MIDI.setHandleControlChange(handleControlChange);
  MIDI.setHandleProgramChange(handleProgramChange);
  MIDI.setHandleNoteOn(handleNoteOn);  // Put only the name of the function
  MIDI.setHandleNoteOff(handleNoteOff); // Do the same for NoteOffs

  Serial.begin(BAUD_RATE);
    if (Usb.Init() == -1) {
    while (1); //halt
  }//if (Usb.Init() == -1...
  delay( 200 );
  MIDI.begin(MIDI_CHANNEL_OMNI);
}

void loop() // Call MIDI.read the fastest you can for real-time performance.
{
  Usb.Task();
  MIDI.read();
}